# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 2.14.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.curia.api.curia.api.curia.api.swagger_client
from curia.api.curia.api.curia.api.curia.api.swagger_client.api.datasets_api import DatasetsApi  # noqa: E501
from curia.api.curia.api.curia.api.curia.api.swagger_client.rest import ApiException


class TestDatasetsApi(unittest.TestCase):
    """DatasetsApi unit test stubs"""

    def setUp(self):
        self.api = DatasetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_many_base_dataset_controller_dataset(self):
        """Test case for create_many_base_dataset_controller_dataset

        Create many Dataset  # noqa: E501
        """
        pass

    def test_create_one_base_dataset_controller_dataset(self):
        """Test case for create_one_base_dataset_controller_dataset

        Create one Dataset  # noqa: E501
        """
        pass

    def test_dataset_controller_calculate_stats(self):
        """Test case for dataset_controller_calculate_stats

        Calculate dataset stats  # noqa: E501
        """
        pass

    def test_dataset_controller_download_dataset(self):
        """Test case for dataset_controller_download_dataset

        Download dataset  # noqa: E501
        """
        pass

    def test_dataset_controller_get_datasets_by_tag(self):
        """Test case for dataset_controller_get_datasets_by_tag

        Retrieve datasets by tag  # noqa: E501
        """
        pass

    def test_dataset_controller_internal_download_dataset(self):
        """Test case for dataset_controller_internal_download_dataset

        Download dataset  # noqa: E501
        """
        pass

    def test_dataset_controller_upload(self):
        """Test case for dataset_controller_upload

        Upload dataset  # noqa: E501
        """
        pass

    def test_dataset_controller_upload_abort(self):
        """Test case for dataset_controller_upload_abort

        cancel multipart upload for large dataset  # noqa: E501
        """
        pass

    def test_dataset_controller_upload_finish(self):
        """Test case for dataset_controller_upload_finish

        complete upload for large dataset using multipart upload  # noqa: E501
        """
        pass

    def test_dataset_controller_upload_multipart_start(self):
        """Test case for dataset_controller_upload_multipart_start

        Initiate upload for large dataset using multipart upload  # noqa: E501
        """
        pass

    def test_delete_one_base_dataset_controller_dataset(self):
        """Test case for delete_one_base_dataset_controller_dataset

        Delete one Dataset  # noqa: E501
        """
        pass

    def test_get_many_base_dataset_controller_dataset(self):
        """Test case for get_many_base_dataset_controller_dataset

        Retrieve many Dataset  # noqa: E501
        """
        pass

    def test_get_one_base_dataset_controller_dataset(self):
        """Test case for get_one_base_dataset_controller_dataset

        Retrieve one Dataset  # noqa: E501
        """
        pass

    def test_replace_one_base_dataset_controller_dataset(self):
        """Test case for replace_one_base_dataset_controller_dataset

        Replace one Dataset  # noqa: E501
        """
        pass

    def test_update_one_base_dataset_controller_dataset(self):
        """Test case for update_one_base_dataset_controller_dataset

        Update one Dataset  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
